import pytest

from util.validation import is_json, validate_label_key


@pytest.mark.parametrize('string_value,expected', [
  ('{}', True),
  ('[]', True),
  ('[hello world]', False),
  ('{hello world}', False),
  ('[test] this is a test', False),
  ('hello world', False),
  ('{"hi": "there"}', True),
  ('[1, 2, 3, 4]', True),
  ('[1, 2, {"num": 3}, 4]', True),
])
def test_is_json(string_value, expected):
  assert is_json(string_value) == expected


@pytest.mark.parametrize('key, is_valid', [
  ('foo', True),
  ('bar', True),

  ('foo1', True),
  ('bar2', True),

  ('1', True),
  ('12', True),
  ('123', True),
  ('1234', True),

  ('git-sha', True),

  ('com.coreos.something', True),
  ('io.quay.git-sha', True),

  ('', False),
  ('git_sha', False),

  ('-125', False),
  ('-foo', False),
  ('foo-', False),
  ('123-', False),

  ('foo--bar', False),
  ('foo..bar', False),
])
def test_validate_label_key(key, is_valid):
  assert validate_label_key(key) == is_valid
